@@ -142,22 +142,6 @@ const Chimera *Chimera::parse(const QByteArray &name)
 }
 
 
-// Parse a meta-property as a type.
-const Chimera *Chimera::parse(const QMetaProperty &mprop)
-{
-    Chimera *ct = new Chimera;
-    const char *type_name = mprop.typeName();
-
-    ct->_type = sipFindType(type_name);
-    ct->_metatype = mprop.userType();
-    ct->_inexact = true;
-    ct->_is_flag = mprop.isFlagType();
-    ct->_name = type_name;
-
-    return ct;
-}
-
-
 // Parse a normalised C++ signature as a list of types.
 Chimera::Signature *Chimera::parse(const QByteArray &sig, const char *context)
 {
