@@ -31,7 +31,6 @@
 
 #include <QByteArray>
 #include <QHash>
-#include <QMetaProperty>
 #include <QVariant>
 
 #include "qpycore_sip.h"
@@ -51,9 +50,6 @@ public:
     // Parses a Python object as a type.  Return 0 if there was an error.
     static const Chimera *parse(PyObject *obj);
 
-    // Parses a Qt meta-property as a type.  Return 0 if there was an error.
-    static const Chimera *parse(const QMetaProperty &mprop);
-
     // Parses a C++ type name as a type.  Return 0 if there was an error.
     static const Chimera *parse(const QByteArray &name);
 
