@@ -59,26 +59,18 @@ int qpycore_pyqtconfigure(PyObject *self, QObject *qobj, PyObject *kwds)
 
         if (idx >= 0)
         {
-            const Chimera *ct = Chimera::parse(mo->property(idx));
+            int value_state, iserr = 0;
 
-            if (!ct)
-            {
-                PyErr_Format(PyExc_TypeError,
-                        "'%s' keyword argument has an invalid type",
-                        enc_name.constData());
+            QVariant *value = reinterpret_cast<QVariant *>(
+                    sipForceConvertToType(value_obj, sipType_QVariant, 0,
+                            SIP_NOT_NONE, &value_state, &iserr));
 
-                return -1;
-            }
-
-            QVariant value;
-            bool valid = ct->fromPyObject(value_obj, &value);
-
-            delete ct;
-
-            if (!valid)
+            if (iserr)
                 return -1;
 
-            qobj->setProperty(enc_name.constData(), value);
+            qobj->setProperty(enc_name.constData(), *value);
+
+            sipReleaseType(value, sipType_QVariant, value_state);
         }
         else
         {
